#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-auth
version:              1.6.11.3
visibility:           public
id:                   yesod-auth-1.6.11.3-GlHTpzzqDDL3PenMpICEeb
key:                  yesod-auth-1.6.11.3-GlHTpzzqDDL3PenMpICEeb
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Patrick Brisbin
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Authentication for Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-auth>

category:             Web, Yesod
abi:                  9908f31da86c688c58dbb0f9cc4d6374
exposed:              True
exposed-modules:
    Yesod.Auth Yesod.Auth.BrowserId Yesod.Auth.Dummy Yesod.Auth.Email
    Yesod.Auth.GoogleEmail2 Yesod.Auth.Hardcoded Yesod.Auth.Message
    Yesod.Auth.OpenId Yesod.Auth.Rpxnow Yesod.Auth.Util.PasswordStore

hidden-modules:       Yesod.Auth.Routes
import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-auth-1.6.11.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-auth-1.6.11.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-auth-1.6.11.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-auth
hs-libraries:         HSyesod-auth-1.6.11.3-GlHTpzzqDDL3PenMpICEeb
depends:
    aeson-2.2.2.0-CZIrLrIqsbVBSATKMNLvxW
    attoparsec-aeson-2.2.0.0-274nrhbbz6KBPTA2z5pMuD
    authenticate-1.3.5.2-FdsCBSiCddS9VuCowIKyf base-4.18.2.1
    base16-bytestring-1.0.2.0-AMtBRFHYCKP9ubQlj6HdMp
    base64-bytestring-1.2.1.0-EIdFd4GQy0qAj5NJhNKnbU binary-0.8.9.1
    blaze-builder-0.4.4.1-8H0R0umV9po1kAX8f2JboT
    blaze-html-0.9.2.0-INVwOgfGe5U7282dcB0sT7
    blaze-markup-0.8.3.0-BSDlvJxAKWg1C6HsRLyif3 bytestring-0.11.5.3
    conduit-1.3.6.1-6TYo6G3gQF79ei7y9Ec7g4
    conduit-extra-1.3.8-BzY3VOSd7uu9X0uJJpRjSX containers-0.6.7
    cryptonite-0.30-8wOVdBVgKl12ruNNtztOD6
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    email-validate-2.3.2.21-4276A2lFS1jF8bKeKN4NBs
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    http-client-0.7.19-1q3y7vnpuvH51ds1r9Weyk
    http-client-tls-0.3.6.4-IPAuQ8vgNUFKOSQuiXp27m
    http-conduit-2.3.9.1-2h1lq59T36j5qSVbTmccvx
    http-types-0.12.4-DWpoveyaOeC1PmowHzh97w
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-uri-2.6.4.2-DZsK30J0JA75RbwwKgdhQI
    nonce-1.0.7-KENzJY1lCU46vKjMRQam8F
    persistent-2.14.5.2-EbEJZYpHZmdEQPemfNs0Am
    random-1.2.1.3-I2hvYvdtJZ4FW6nqBcrw73
    safe-0.3.21-9LQlXkQq5dJFD7zwcgmche
    shakespeare-2.1.7.1-JR6tVW14P5r5PXM4psLlzm
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unliftio-0.2.25.1-2In9ZMbNHRKIca2kbOdPHJ
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-170HxTRPWLJC6Js92iIt2k
    wai-3.2.4-5DXE2ni3kE56pZVIt6j1J4
    yesod-core-1.6.27.1-CKbYWALrbUC9sBCQe2aItB
    yesod-form-1.7.9.2-3RzRDrkG8WL73Mnlz4GO4D
    yesod-persistent-1.6.0.8-KlGmzC5P9kc9JzDHroYPCp

haddock-interfaces:   /usr/share/doc/haskell-yesod-auth/html/yesod-auth.haddock
haddock-html:         /usr/share/doc/haskell-yesod-auth/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

